<?php
/**
 * @package   Nicepage Website Builder
 * @author    Nicepage https://www.nicepage.com
 * @copyright Copyright (c) 2016 - 2019 Nicepage
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
 */

namespace NP\Virtuemart;

defined('_JEXEC') or die;

use \VmModel;
use \JFactory;

/**
 * Class ProductMapper
 */
class ProductMapper
{
    /**
     * Get product model
     *
     * @return mixed
     */
    public static function getModel()
    {
        return VmModel::getModel('product');
    }

    /**
     * Create product
     *
     * @param array $data
     *
     * @return mixed
     */
    public static function create($data)
    {
        return self::getModel()->store($data);
    }

    /**
     * Get products by category id
     *
     * @param integer $catid
     *
     * @return mixed
     */
    public static function getProductsByCatId($catid)
    {
        $ids = self::getModel()->sortSearchListQuery(false, $catid, false, false);
        return self::getModel()->getProducts($ids, false, false, false, true);
    }

    /**
     * Remove product by id
     *
     * @param integer $id
     *
     * @return mixed
     */
    public static function delete($id)
    {
        return self::getModel()->remove(array($id));
    }

    /**
     * Update date for product
     *
     * @param integer $id Product id
     */
    public static function updateDate($id)
    {
        $date = JFactory::getDate();
        $date->modify('-1 second');
        $strDate = $date->toSql();
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query->update('#__virtuemart_products');
        $query->set($db->quoteName('modified_on') . '=' . $db->quote($strDate));
        $query->set($db->quoteName('created_on') . '=' . $db->quote($strDate));
        $query->where('virtuemart_product_id=' . $id);
        $db->setQuery($query);
        $db->execute();
    }
}
